@@ -3,7 +3,7 @@ BEGIN {
   $Dancer::App::AUTHORITY = 'cpan:SUKRIA';
 }
 # ABSTRACT: Base application class for Dancer.
-$Dancer::App::VERSION = '1.3134';
+$Dancer::App::VERSION = '1.3135';
 use strict;
 use warnings;
 use Carp;
@@ -14,6 +14,7 @@ use Dancer::ModuleLoader;
 use Dancer::Route::Registry;
 use Dancer::Logger;
 use Dancer::Exception qw(:all);
+use Dancer::Deprecation;
 
 Dancer::App->attributes(qw(name app_prefix prefix registry settings on_lexical_prefix));
 
@@ -91,6 +92,11 @@ sub routes {
 sub reload_apps {
     my ($class) = @_;
 
+    Dancer::Deprecation->deprecated(
+        feature => 'auto_reload',
+        reason => 'use plackup -r instead',
+    );
+
     my @missing_modules = grep { not Dancer::ModuleLoader->load($_) }
         qw(Module::Refresh Clone);
 
@@ -253,7 +259,7 @@ Dancer::App - Base application class for Dancer.
 
 =head1 VERSION
 
-version 1.3134
+version 1.3135
 
 =head1 AUTHOR
 
