@@ -3,7 +3,7 @@ BEGIN {
   $Dancer::Handler::AUTHORITY = 'cpan:SUKRIA';
 }
 # ABSTRACT: Dancer request handler
-$Dancer::Handler::VERSION = '1.3134';
+$Dancer::Handler::VERSION = '1.3135';
 use strict;
 use warnings;
 use Carp;
@@ -73,9 +73,7 @@ sub handle_request {
 
     Dancer::Cookies->init;
 
-    if (Dancer::Config::setting('auto_reload')) {
-        Dancer::App->reload_apps;
-    }
+    Dancer::App->reload_apps if Dancer::Config::setting('auto_reload');
 
     render_request($request);
     return $self->render_response();
@@ -226,7 +224,7 @@ Dancer::Handler - Dancer request handler
 
 =head1 VERSION
 
-version 1.3134
+version 1.3135
 
 =head1 AUTHOR
 
